Clock

Trait Clock 

pub trait Clock {
    // Required method
    fn delta(&mut self) -> f32;
}
Provides a delta-time value for each animation frame.

Implementors return the number of seconds elapsed since the last call to Clock::delta.

Required Methods

fn delta(&mut self) -> f32

Returns seconds elapsed since the last call to delta().

Implementors

Source

impl Clock for ScrollClock

Source

impl Clock for ManualClock

Source

impl Clock for MockClock

Source

impl Clock for WallClock

Available on crate feature std only.