pub trait Clock {
// Required method
fn delta(&mut self) -> f32;
}Expand description
Provides a delta-time value for each animation frame.
Implementors return the number of seconds elapsed since the last call
to Clock::delta.
pub trait Clock {
// Required method
fn delta(&mut self) -> f32;
}Provides a delta-time value for each animation frame.
Implementors return the number of seconds elapsed since the last call
to Clock::delta.